# Stubs for xlwt.CompoundDoc (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class XlsDoc:
    SECTOR_SIZE: int = ...
    MIN_LIMIT: int = ...
    SID_FREE_SECTOR: int = ...
    SID_END_OF_CHAIN: int = ...
    SID_USED_BY_SAT: int = ...
    SID_USED_BY_MSAT: int = ...
    book_stream_sect: Any = ...
    dir_stream: str = ...
    dir_stream_sect: Any = ...
    packed_SAT: str = ...
    SAT_sect: Any = ...
    packed_MSAT_1st: str = ...
    packed_MSAT_2nd: str = ...
    MSAT_sect_2nd: Any = ...
    header: str = ...
    def __init__(self) -> None: ...
    book_stream_len: Any = ...
    def save(self, file_name_or_filelike_obj: Any, stream: Any) -> None: ...
