# Stubs for xlwt.Row (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

class Row:
    height: int = ...
    has_default_height: int = ...
    height_mismatch: int = ...
    level: int = ...
    collapse: int = ...
    hidden: int = ...
    space_above: int = ...
    space_below: int = ...
    def __init__(self, rowx: Any, parent_sheet: Any) -> None: ...
    def get_height_in_pixels(self): ...
    def set_style(self, style: Any) -> None: ...
    def get_xf_index(self): ...
    def get_cells_count(self): ...
    def get_min_col(self): ...
    def get_max_col(self): ...
    def get_row_biff_data(self): ...
    def insert_cell(self, col_index: Any, cell_obj: Any) -> None: ...
    def insert_mulcells(self, colx1: Any, colx2: Any, cell_obj: Any) -> None: ...
    def get_cells_biff_data(self): ...
    def get_index(self): ...
    def set_cell_text(self, colx: Any, value: Any, style: Any = ...) -> None: ...
    def set_cell_blank(self, colx: Any, style: Any = ...) -> None: ...
    def set_cell_mulblanks(self, first_colx: Any, last_colx: Any, style: Any = ...) -> None: ...
    def set_cell_number(self, colx: Any, number: Any, style: Any = ...) -> None: ...
    def set_cell_date(self, colx: Any, datetime_obj: Any, style: Any = ...) -> None: ...
    def set_cell_formula(self, colx: Any, formula: Any, style: Any = ..., calc_flags: int = ...) -> None: ...
    def set_cell_boolean(self, colx: Any, value: Any, style: Any = ...) -> None: ...
    def set_cell_error(self, colx: Any, error_string_or_code: Any, style: Any = ...) -> None: ...
    def write(self, col: Any, label: Any, style: Any = ...) -> None: ...
    def set_cell_rich_text(self, col: Any, rich_text_list: Any, style: Any = ...) -> None: ...
    write_blanks: Any = ...
    write_rich_text: Any = ...
