# Stubs for xlwt.compat (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

PY3: Any
unicode: Any
unicode_type = str
basestring = str
xrange = range
int_types: Any
long = int

