# Stubs for xlrd (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .biffh import XLRDError, XL_CELL_BLANK, XL_CELL_BOOLEAN, XL_CELL_DATE, XL_CELL_EMPTY, XL_CELL_ERROR, XL_CELL_NUMBER, XL_CELL_TEXT, biff_text_from_num, error_text_from_code
from .book import Book as Book, colname as colname
from .sheet import empty_cell as empty_cell
from .xldate import XLDateError, xldate_as_datetime, xldate_as_tuple
from .xlsx import X12Book as X12Book
from typing import Any, Optional

MMAP_AVAILABLE: int
USE_MMAP = MMAP_AVAILABLE

def open_workbook(filename: Optional[Any] = ..., logfile: Any = ..., verbosity: int = ..., use_mmap: Any = ..., file_contents: Optional[Any] = ..., encoding_override: Optional[Any] = ..., formatting_info: bool = ..., on_demand: bool = ..., ragged_rows: bool = ...): ...
def dump(filename: Any, outfile: Any = ..., unnumbered: bool = ...) -> None: ...
def count_records(filename: Any, outfile: Any = ...) -> None: ...
