# Stubs for xlwt (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from .Column import Column as Column
from .Formatting import Alignment, Borders, Font, Pattern, Protection
from .Row import Row as Row
from .Style import XFStyle as XFStyle, easyfont as easyfont, easyxf as easyxf
from .Workbook import Workbook as Workbook
from .Worksheet import Worksheet as Worksheet


__VERSION__: str
