# Stubs for xlwt.UnicodeUtils (Python 3)
#
# NOTE: This dynamically typed stub was automatically generated by stubgen.

from typing import Any

def upack2(s: Any, encoding: str = ...): ...
def upack2rt(rt: Any, encoding: str = ...): ...
def upack1(s: Any, encoding: str = ...): ...
